==> Flask-MarcoPolo-0.6.1.tar.gz: Flask-MarcoPolo-0.6.1/setup.py <==
"""
Flask-MarcoPolo
"""

from setuptools import setup, find_packages

import flask_marcopolo.pkg


PACKAGE = flask_marcopolo.pkg

setup(
    name=PACKAGE.__NAME__,
    version=PACKAGE.__version__,
    license=PACKAGE.__license__,
    author=PACKAGE.__author__,
    author_email='mardix@github.com',
    description=PACKAGE.__doc__,
    long_description=PACKAGE.__doc__,
    url='http://mardix.github.io/flask-marcopolo/',
    download_url='http://github.com/mardix/flask-marcopolo/tarball/master',
    py_modules=['flask_marcopolo'],
    entry_points=dict(console_scripts=['flask-marcopolo=flask_marcopolo.cmd:main']),
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        'Flask==0.10.1',
        'Flask-Classy==0.6.10',
        'Flask-Assets==0.10',
        'Flask-Mail==0.9.1',
        'Flask-WTF==0.9.5'
    ],

    keywords=['flask', 'templates', 'views', 'classy', 'marcopolo', 'framework', "mvc"],
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    zip_safe=False
)

==> Flask-MarcoPolo-0.6.3.tar.gz: Flask-MarcoPolo-0.6.3/setup.py <==
"""
Flask-MarcoPolo

Flask-MarcoPolo is a Flask extension that adds structure to both your views and
templates, by mapping them to each other to provide a rapid application development framework.
The extension also comes with Flask-Classy, Flask-Assets, Flask-Mail,
JQuery 2.x, Bootstrap 3.x, Font-Awesome, Bootswatch templates.
The extension also provides pre-made templates for error pages and macros.

https://github.com/mardix/flask-marcopolo

"""

from setuptools import setup, find_packages

__NAME__ = "Flask-MarcoPolo"
__version__ = "0.6.3"
__author__ = "Mardix"
__license__ = "MIT"
__copyright__ = "(c) 2014 Mardix"


setup(
    name=__NAME__,
    version=__version__,
    license=__license__,
    author=__author__,
    author_email='mardix@github.com',
    description=__doc__,
    long_description=__doc__,
    url='http://mardix.github.io/flask-marcopolo/',
    download_url='http://github.com/mardix/flask-marcopolo/tarball/master',
    py_modules=['flask_marcopolo'],
    entry_points=dict(console_scripts=['flask-marcopolo=flask_marcopolo.cmd:main']),
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        'Flask==0.10.1',
        'Flask-Classy==0.6.10',
        'Flask-Assets==0.10',
        'Flask-Mail==0.9.1',
        'Flask-WTF==0.9.5'
    ],

    keywords=['flask', 'templates', 'views', 'classy', 'marcopolo', 'framework', "mvc"],
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    zip_safe=False
)
